==> haskell-comonad-5.0.9-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 comonad
version:              5.0.9
visibility:           public
id:                   comonad-5.0.9-DcjlGJ2nFITBh9RczgN9OW
key:                  comonad-5.0.9-DcjlGJ2nFITBh9RczgN9OW
license:              BSD-3-Clause
copyright:
    Copyright (C) 2008-2014 Edward A. Kmett,
    Copyright (C) 2004-2008 Dave Menendez

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/comonad/
synopsis:             Comonads
description:          Comonads.
category:             Control, Comonads
abi:                  9b3623c09a6e936c617e51543088cca9
exposed:              True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition

import-dirs:          /usr/lib/ghc-9.4.8/site-local/comonad-5.0.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/comonad-5.0.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/comonad-5.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-comonad
hs-libraries:         HScomonad-5.0.9-DcjlGJ2nFITBh9RczgN9OW
depends:
    base-4.17.2.1 containers-0.6.7
    distributive-0.6.2.1-JWrRvxW4M5uLlDVH9ni0Nb
    indexed-traversable-0.1.4-9YXKO6oMx1B7bSWe0dnRh7
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html:         /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-comonad-5.0.9-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 comonad
version:              5.0.9
visibility:           public
id:                   comonad-5.0.9-4R4IfV9XZS88cmPqlpNv0r
key:                  comonad-5.0.9-4R4IfV9XZS88cmPqlpNv0r
license:              BSD-3-Clause
copyright:
    Copyright (C) 2008-2014 Edward A. Kmett,
    Copyright (C) 2004-2008 Dave Menendez

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/comonad/
synopsis:             Comonads
description:          Comonads.
category:             Control, Comonads
abi:                  25ba92102094c3f4f5d3926e142ac93f
exposed:              True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition

import-dirs:          /usr/lib/ghc-9.4.8/site-local/comonad-5.0.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/comonad-5.0.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/comonad-5.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-comonad
hs-libraries:         HScomonad-5.0.9-4R4IfV9XZS88cmPqlpNv0r
depends:
    base-4.17.2.1 containers-0.6.7
    distributive-0.6.2.1-KCd9v3pBV8FHCEk0ReEHSP
    indexed-traversable-0.1.4-8dufgEA3LInFduylpBTbnE
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html:         /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
